@@ -1,6 +1,17 @@
 from typing_extensions import TypedDict
 from typing import List, Optional
 from datetime import datetime
+from enum import Enum
+
+
+CopyFactoryStrategySymbolMapping = TypedDict(
+    "CopyFactoryStrategySymbolMapping",
+    {
+        "from": str,  # Symbol name to convert from.
+        "to": str  # Symbol name to convert to.
+    }
+)
+"""CopyFactory strategy symbol mapping."""
 
 
 class CopyFactoryStrategyIdAndName(TypedDict):
@@ -147,6 +158,9 @@ class CopyFactoryStrategySubscription(TypedDict):
     maxLeverage: Optional[float]
     """Optional setting indicating maximum leverage allowed when opening a new positions. Any trade which results in a
     higher leverage will be discarded."""
+    symbolMapping: List[CopyFactoryStrategySymbolMapping]
+    """Defines how symbol name should be changed when trading (e.g. when broker uses symbol names with unusual
+    suffixes). By default this setting is disabled and the trades are copied using signal source symbol name."""
 
 
 class CopyFactoryAccountUpdate(TypedDict):
@@ -274,6 +288,9 @@ class CopyFactoryStrategyUpdate(TypedDict):
     timeSettings: Optional[CopyFactoryStrategyTimeSettings]
     """Settings to manage copying timeframe and position lifetime. Default is to copy position within 1 minute from
     being opened at source and let the position to live for up to 90 days."""
+    symbolMapping: List[CopyFactoryStrategySymbolMapping]
+    """Defines how symbol name should be changed when trading (e.g. when broker uses symbol names with unusual
+    suffixes). By default this setting is disabled and the trades are copied using signal source symbol name."""
 
 
 class CopyFactorySubscriberOrProvider(TypedDict):
@@ -402,6 +419,9 @@ class CopyFactoryPortfolioMember(TypedDict):
     maxLeverage: Optional[float]
     """Optional max leverage risk restriction. All trades resulting in a leverage value higher than specified will be
     skipped."""
+    symbolMapping: List[CopyFactoryStrategySymbolMapping]
+    """Defines how symbol name should be changed when trading (e.g. when broker uses symbol names with unusual
+    suffixes). By default this setting is disabled and the trades are copied using signal source symbol name."""
 
 
 class CopyFactoryPortfolioStrategyUpdate(TypedDict):
@@ -441,6 +461,9 @@ class CopyFactoryPortfolioStrategyUpdate(TypedDict):
     maxLeverage: Optional[float]
     """Optional max leverage risk restriction. All trades resulting in a leverage value higher than specified will be
     skipped."""
+    symbolMapping: List[CopyFactoryStrategySymbolMapping]
+    """Defines how symbol name should be changed when trading (e.g. when broker uses symbol names with unusual
+    suffixes). By default this setting is disabled and the trades are copied using signal source symbol name."""
 
 
 class CopyFactoryPortfolioStrategy(CopyFactoryPortfolioStrategyUpdate):
@@ -450,3 +473,34 @@ class CopyFactoryPortfolioStrategy(CopyFactoryPortfolioStrategyUpdate):
     platformCommissionRate: float
     """Commission rate the platform charges for strategy copying, applied to commissions charged by provider. This
     commission applies only to accounts not managed directly by provider. Should be fraction of 1."""
+
+
+class LogLevel(Enum):
+    """Log level."""
+    INFO = 'INFO'
+    WARN = 'WARN'
+    ERROR = 'ERROR'
+
+
+class CopyFactoryUserLogRecord(TypedDict):
+    """Trade copying user log record."""
+    time: datetime
+    """Log record time."""
+    level: LogLevel
+    """Log level. One of INFO, WARN, ERROR."""
+    message: str
+    """Log message."""
+    symbol: Optional[str]
+    """Symbol traded."""
+    strategyId: Optional[str]
+    """Id of the strategy event relates to."""
+    strategyName: Optional[str]
+    """Name of the strategy event relates to."""
+    positionId: Optional[str]
+    """Position id event relates to."""
+    side: Optional[str]
+    """Side of the trade event relates to. One of buy, sell, close."""
+    type: Optional[str]
+    """Type of the trade event relates to. One of market, limit, stop."""
+    openPrice: Optional[float]
+    """Open price for limit and stop orders."""
