@@ -17,7 +17,6 @@ from typing_extensions import TypedDict
 from functools import reduce
 import pytz
 import asyncio
-from threading import Timer
 
 
 class MetaApiConnectionDict(TypedDict):
@@ -822,12 +821,14 @@ class MetaApiConnection(SynchronizationListener, ReconnectListener):
                 return acc
             nonlocal synchronization_id
             synchronization_id = synchronization_id or s['lastSynchronizationId']
-            synchronized = bool(s['ordersSynchronized'][synchronization_id]) and \
+            synchronized = synchronization_id in s['ordersSynchronized'] and \
+                bool(s['ordersSynchronized'][synchronization_id]) and \
+                synchronization_id in s['dealsSynchronized'] and \
                 bool(s['dealsSynchronized'][synchronization_id])
             return acc or synchronized
 
-        return reduce(reducer_func, self._stateByInstanceIndex.values()) if len(self._stateByInstanceIndex.values())\
-            else False
+        return reduce(reducer_func, self._stateByInstanceIndex.values(), False) if \
+            len(self._stateByInstanceIndex.values()) else False
 
     async def wait_synchronized(self, opts: SynchronizationOptions = None):
         """Waits until synchronization to MetaTrader terminal is completed.
@@ -923,10 +924,11 @@ class MetaApiConnection(SynchronizationListener, ReconnectListener):
                 print(f'[{datetime.now().isoformat()}] MetaApi websocket client for account ' + self.account.id +
                       ':' + str(instance_index) + ' failed to synchronize', err)
                 if state['shouldSynchronize'] == key:
-                    def restart_ensure_sync():
-                        asyncio.run(self._ensure_synchronized(instance_index, key))
-                    self._ensure_sync_timer = Timer(state['synchronizationRetryIntervalInSeconds'], restart_ensure_sync)
-                    self._ensure_sync_timer.start()
+
+                    async def restart_ensure_sync():
+                        await asyncio.sleep(state['synchronizationRetryIntervalInSeconds'])
+                        await self._ensure_synchronized(instance_index, key)
+                    asyncio.create_task(restart_ensure_sync())
                     state['synchronizationRetryIntervalInSeconds'] = \
                         min(state['synchronizationRetryIntervalInSeconds'] * 2, 300)
 
